"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const intId_1 = __importDefault(require("./intId"));
class TestIntId extends intId_1.default {
    get symbol() {
        return Symbol();
    }
}
describe('IntId', () => {
    it('should create intId', () => {
        expect(TestIntId.create(123).value).toBe(123);
        expect(TestIntId.create(123.1).value).toBe(123);
        expect(TestIntId.create('123').value).toBe(123);
        expect(TestIntId.create('123').isSet()).toBe(true);
    });
    it('should compare intId', () => {
        const intId1 = TestIntId.create(123);
        const intId2 = TestIntId.create(456);
        const intId3 = TestIntId.create('456');
        expect(intId1.compare(intId2)).toBe(-1);
        expect(intId2.compare(intId1)).toBe(1);
        expect(intId2.compare(intId3)).toBe(0);
        expect(intId1.equals(intId2)).toBe(false);
        expect(intId2.equals(intId3)).toBe(true);
    });
    it('should get errors', () => {
        expect(TestIntId.create('123').getErrors('test')).toBeUndefined();
        expect(TestIntId.create(null).getErrors('test')).toBeUndefined();
        expect(TestIntId.create('').getErrors('test')).toEqual([{ name: 'test', error: '整数の形式が正しくありません' }]);
        expect(TestIntId.create('10000000000000000').getErrors('test')).toEqual([{ name: 'test', error: '有効な整数ではありません' }]);
    });
    it('should throw error if id is not set', () => {
        const id = TestIntId.create(null);
        expect(id.isSet()).toBe(false);
        expect(() => id.value).toThrow('無効な値です');
    });
});
//# sourceMappingURL=intId.spec.js.map